[Mesa-dev] [PATCH] mesa: fix error type for GetFramebufferAttachmentParameteriv

Tapani Pälli tapani.palli at intel.com
Tue Oct 27 00:11:11 PDT 2015


Fixes following failing dEQP test:
   dEQP-GLES3.functional.fbo.api.attachment_query_empty_fbo

Signed-off-by: Tapani Pälli <tapani.palli at intel.com>
Bugzilla: https://bugs.freedesktop.org/show_bug.cgi?id=92649
Cc: "11.0" <mesa-stable at lists.freedesktop.org>
---
 src/mesa/main/fbobject.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/mesa/main/fbobject.c b/src/mesa/main/fbobject.c
index fe6bdc2..d91fb4a 100644
--- a/src/mesa/main/fbobject.c
+++ b/src/mesa/main/fbobject.c
@@ -3540,8 +3540,9 @@ _mesa_get_framebuffer_attachment_parameter(struct gl_context *ctx,
    const struct gl_renderbuffer_attachment *att;
    GLenum err;
 
-   /* The error differs in GL and GLES. */
-   err = _mesa_is_desktop_gl(ctx) ? GL_INVALID_OPERATION : GL_INVALID_ENUM;
+   /* The error differs between GL/GLES3 and GLES 2.0. */
+   err = _mesa_is_desktop_gl(ctx) || _mesa_is_gles3(ctx) ?
+      GL_INVALID_OPERATION : GL_INVALID_ENUM;
 
    if (_mesa_is_winsys_fbo(buffer)) {
       /* Page 126 (page 136 of the PDF) of the OpenGL ES 2.0.25 spec
-- 
2.4.3



More information about the mesa-dev mailing list